"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getAuthUser = exports.refreshToken = exports.resetPassword = exports.forgetPassword = exports.signOut = exports.signIn = void 0;

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _services = require("../services");

var _utils = require("../utils");

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { (0, _defineProperty2.default)(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

const signIn = async (_ref, url) => {
  let {
    email,
    password
  } = _ref;
  const result = await _services.authServices.signIn({
    email,
    password
  }, url);
  return result;
};

exports.signIn = signIn;

const signOut = async (_ref2, dispatch, config) => {
  let {
    onLogout
  } = _ref2;

  _utils.auth.logout(onLogout);

  dispatch({
    type: "REMOVE_AUTH_USER"
  });
};

exports.signOut = signOut;

const forgetPassword = async (_ref3, url) => {
  let {
    email
  } = _ref3;
  const result = await _services.authServices.forgetPassword({
    email
  }, url);
  return result;
};

exports.forgetPassword = forgetPassword;

const resetPassword = async (_ref4, url) => {
  let {
    key,
    login,
    password
  } = _ref4;
  const result = await _services.authServices.resetPassword({
    key,
    login,
    password
  }, url);
  return result;
};

exports.resetPassword = resetPassword;

const refreshToken = async (_ref5, dispatch, config) => {
  let {} = _ref5;

  const {
    refreshToken
  } = _utils.auth.getUser();

  if (refreshToken) {
    const authToken = await _services.authServices.refreshToken({
      refreshToken
    }, dispatch, config);

    if (authToken) {
      const user = _utils.auth.getUser(); // Overwrite auth token


      _utils.auth.setUser(_objectSpread(_objectSpread({}, user), {}, {
        authToken
      }));
    } else {
      signOut({}, dispatch, config);
    }
  }
};

exports.refreshToken = refreshToken;

const getAuthUser = async (_ref6, dispatch, config) => {
  let {} = _ref6;
  const result = await _services.authServices.getAuthUser({}, dispatch, config);

  if (result) {
    const {
      jwtAuthExpiration
    } = result;

    const user = _utils.auth.getUser(); // Overwrite jwtAuthExpiration


    _utils.auth.setUser(_objectSpread(_objectSpread({}, user), {}, {
      jwtAuthExpiration
    }));

    dispatch({
      type: "ADD_AUTH_USER",
      payload: result
    });
  } else {
    signOut({}, dispatch, config);
  }

  return result;
};

exports.getAuthUser = getAuthUser;