"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _taggedTemplateLiteral2 = _interopRequireDefault(require("@babel/runtime/helpers/taggedTemplateLiteral"));

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _react = _interopRequireWildcard(require("react"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _router = require("@reach/router");

var _antd = require("antd");

var _Input = _interopRequireDefault(require("./Input"));

var _actions = require("../actions");

var _routes = require("../routes");

var _utils = require("../utils");

var _theme = require("../theme");

var _templateObject, _templateObject2, _templateObject3, _templateObject4, _templateObject5;

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { (0, _defineProperty2.default)(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

const LoginForm = props => {
  const {
    url,
    backLink = false,
    isAdmin = false
  } = props;
  const [data, setData] = (0, _react.useState)({
    email: '',
    password: '',
    error: null,
    success: null,
    loading: false,
    form: ''
  });
  const action = (0, _utils.getParameter)('action');
  const key = (0, _utils.getParameter)('key');
  const login = (0, _utils.getParameter)('login');

  const isAuthed = _utils.auth.isLoggedIn();

  (0, _react.useEffect)(() => {
    setData(_objectSpread(_objectSpread({}, data), {}, {
      form: action && key && login ? action : 'login'
    }));
  }, [action]); // Navigate to jamCMS backend if this is admin form

  (0, _react.useEffect)(() => {
    if (isAuthed) {
      if (isAdmin) {
        (0, _router.navigate)(_routes.ROUTE_APP);
      } else {
        (0, _router.navigate)(window.location.pathname);
      }
    }
  }, [isAuthed]);

  const handleChange = e => setData(_objectSpread(_objectSpread({}, data), {}, {
    error: null,
    [e.target.name]: e.target.value
  }));

  const handleLogin = async () => {
    const {
      email,
      password
    } = data;

    if (!email) {
      setData(_objectSpread(_objectSpread({}, data), {}, {
        error: 'Email address is required'
      }));
      return;
    }

    if (!(0, _utils.validateEmail)(email)) {
      setData(_objectSpread(_objectSpread({}, data), {}, {
        error: 'Email address is invalid'
      }));
      return;
    }

    if (!password) {
      setData(_objectSpread(_objectSpread({}, data), {}, {
        error: 'Password is required'
      }));
      return;
    }

    setData(_objectSpread(_objectSpread({}, data), {}, {
      loading: true
    }));

    try {
      var _result$capabilities;

      const result = await _actions.authActions.signIn({
        email,
        password
      }, url); // While technically logging in as i.e. a subscriber succeeds, we gonna display an error message instead if user doesn't have level 1 capabilities.

      if (!(result !== null && result !== void 0 && result.authToken) || isAdmin && !(result !== null && result !== void 0 && (_result$capabilities = result.capabilities) !== null && _result$capabilities !== void 0 && _result$capabilities.level_1)) {
        setData(_objectSpread(_objectSpread({}, data), {}, {
          error: 'Email or password wrong.',
          loading: false
        }));
      } else {
        _utils.auth.setUser(result);

        setData(_objectSpread(_objectSpread({}, data), {}, {
          loading: false
        }));
      }
    } catch (err) {
      console.log('error...: ', err);

      _antd.message.error({
        content: 'Oops, something went wrong'
      });
    }
  };

  const handleForgetPassword = async () => {
    const {
      email
    } = data;

    if (!email) {
      setData(_objectSpread(_objectSpread({}, data), {}, {
        error: 'Email address is required'
      }));
      return;
    }

    if (!(0, _utils.validateEmail)(email)) {
      setData(_objectSpread(_objectSpread({}, data), {}, {
        error: 'Email address is invalid'
      }));
      return;
    }

    setData(_objectSpread(_objectSpread({}, data), {}, {
      loading: true
    }));

    try {
      var _result$data;

      const result = await _actions.authActions.forgetPassword({
        email
      }, url);

      if (result !== null && result !== void 0 && (_result$data = result.data) !== null && _result$data !== void 0 && _result$data.sendPasswordResetEmail) {
        setData(_objectSpread(_objectSpread({}, data), {}, {
          success: /*#__PURE__*/_react.default.createElement("p", null, "Success. An email has been sent to ".concat(email, " with further instructions.")),
          loading: false
        }));
      } else {
        var _result$errors, _result$errors$;

        setData(_objectSpread(_objectSpread({}, data), {}, {
          error: result === null || result === void 0 ? void 0 : (_result$errors = result.errors) === null || _result$errors === void 0 ? void 0 : (_result$errors$ = _result$errors[0]) === null || _result$errors$ === void 0 ? void 0 : _result$errors$.message,
          loading: false
        }));
      }
    } catch (err) {
      console.log('error...: ', err);
    }
  };

  const handleSetPassword = async () => {
    const {
      password
    } = data;

    if (!password) {
      setData(_objectSpread(_objectSpread({}, data), {}, {
        error: 'Password is required'
      }));
      return;
    }

    setData(_objectSpread(_objectSpread({}, data), {}, {
      loading: true
    }));

    try {
      var _result$data2;

      const result = await _actions.authActions.resetPassword({
        key,
        login,
        password
      }, url);

      if (result !== null && result !== void 0 && (_result$data2 = result.data) !== null && _result$data2 !== void 0 && _result$data2.resetUserPassword) {
        setData(_objectSpread(_objectSpread({}, data), {}, {
          password: '',
          success: /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement("p", null, "Password set successfully."), /*#__PURE__*/_react.default.createElement(_antd.Button, {
            children: "Back to Login",
            onClick: () => setData(_objectSpread(_objectSpread({}, data), {}, {
              form: 'login'
            })),
            type: "primary",
            block: true
          })),
          loading: false
        }));
      } else {
        var _result$errors2, _result$errors2$;

        setData(_objectSpread(_objectSpread({}, data), {}, {
          error: result === null || result === void 0 ? void 0 : (_result$errors2 = result.errors) === null || _result$errors2 === void 0 ? void 0 : (_result$errors2$ = _result$errors2[0]) === null || _result$errors2$ === void 0 ? void 0 : _result$errors2$.message,
          loading: false
        }));
      }
    } catch (err) {
      console.log('error...: ', err);
    }
  };

  const getFormData = () => {
    switch (data.form) {
      case 'login':
        return {
          title: 'Login',
          handleSubmit: () => handleLogin()
        };

      case 'forget':
        return {
          title: 'Forgot Password',
          handleSubmit: () => handleForgetPassword()
        };

      case 'reset':
        return {
          title: 'Set Password',
          handleSubmit: () => handleSetPassword()
        };

      default:
    }
  };

  const formData = getFormData();
  return /*#__PURE__*/_react.default.createElement(Container, {
    className: "jam-cms"
  }, /*#__PURE__*/_react.default.createElement(Box, null, (data === null || data === void 0 ? void 0 : data.form) && /*#__PURE__*/_react.default.createElement(_antd.Card, {
    title: formData === null || formData === void 0 ? void 0 : formData.title
  }, url ? /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, data !== null && data !== void 0 && data.success ? /*#__PURE__*/_react.default.createElement(Success, {
    children: data.success
  }) : /*#__PURE__*/_react.default.createElement(_antd.Space, {
    direction: "vertical",
    size: 20
  }, /*#__PURE__*/_react.default.createElement(_antd.Form, {
    id: "form",
    onFinish: formData === null || formData === void 0 ? void 0 : formData.handleSubmit
  }, /*#__PURE__*/_react.default.createElement(_antd.Space, {
    direction: "vertical",
    size: 20
  }, (data.form === 'login' || data.form === 'forget') && /*#__PURE__*/_react.default.createElement(_Input.default, {
    id: "email",
    label: "Email",
    value: data.email,
    onChange: handleChange,
    onKeyDown: e => e.key === 'Enter' && (formData === null || formData === void 0 ? void 0 : formData.handleSubmit),
    name: "email"
  }), (data.form === 'login' || data.form === 'reset') && /*#__PURE__*/_react.default.createElement(_Input.default, {
    id: "password",
    label: "Password",
    value: data.password,
    type: "password",
    onChange: handleChange,
    onKeyDown: e => e.key === 'Enter' && (formData === null || formData === void 0 ? void 0 : formData.handleSubmit),
    name: "password"
  }), (data === null || data === void 0 ? void 0 : data.error) && /*#__PURE__*/_react.default.createElement(Error, {
    children: data.error
  }), /*#__PURE__*/_react.default.createElement(_antd.Button, {
    id: "submit",
    loading: data.loading,
    children: "Submit",
    type: "primary",
    htmlType: "submit",
    block: true
  }))), /*#__PURE__*/_react.default.createElement(FooterLink, {
    onClick: () => handleChange({
      target: {
        name: 'form',
        value: data.form === 'login' ? 'forget' : 'login'
      }
    })
  }, data.form === 'login' ? 'Forgot password?' : 'Back to Login'))) : /*#__PURE__*/_react.default.createElement("p", null, "Please provide a URL."))), backLink && /*#__PURE__*/_react.default.createElement(_antd.Row, {
    justify: "center"
  }, /*#__PURE__*/_react.default.createElement(_router.Link, {
    to: '/'
  }, /*#__PURE__*/_react.default.createElement(_antd.Button, {
    type: "text",
    children: "Back to Homepage",
    size: "small"
  }))));
};

const Container = _styledComponents.default.div(_templateObject || (_templateObject = (0, _taggedTemplateLiteral2.default)(["\n  letter-spacing: normal;\n  font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, 'Helvetica Neue', Arial,\n    'Noto Sans', sans-serif, 'Apple Color Emoji', 'Segoe UI Emoji', 'Segoe UI Symbol',\n    'Noto Color Emoji';\n\n  .ant-space {\n    width: 100%;\n  }\n"])));

const Box = _styledComponents.default.div(_templateObject2 || (_templateObject2 = (0, _taggedTemplateLiteral2.default)(["\n  margin-bottom: 20px;\n"])));

const Success = _styledComponents.default.div(_templateObject3 || (_templateObject3 = (0, _taggedTemplateLiteral2.default)(["\n  color: ", ";\n"])), _theme.colors.success);

const Error = _styledComponents.default.div(_templateObject4 || (_templateObject4 = (0, _taggedTemplateLiteral2.default)(["\n  margin-top: 10px;\n  color: ", ";\n"])), _theme.colors.danger);

const FooterLink = _styledComponents.default.p(_templateObject5 || (_templateObject5 = (0, _taggedTemplateLiteral2.default)(["\n  margin: 10px 0 0;\n  text-align: center;\n  color: ", ";\n  cursor: pointer;\n\n  &:hover {\n    text-decoration: underline;\n  }\n"])), _theme.colors.primary);

var _default = LoginForm;
exports.default = _default;