"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _taggedTemplateLiteral2 = _interopRequireDefault(require("@babel/runtime/helpers/taggedTemplateLiteral"));

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _react = _interopRequireWildcard(require("react"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _antd = require("antd");

var _icons = require("@ant-design/icons");

var _reactUseKeypress = _interopRequireDefault(require("react-use-keypress"));

var _router = require("@reach/router");

var _EditorWrapper = _interopRequireDefault(require("./EditorWrapper"));

var _Loader = _interopRequireDefault(require("../Loader"));

var _Sidebar = _interopRequireDefault(require("./Sidebar"));

var _Editor = _interopRequireDefault(require("./Editor"));

var _utils = require("../../utils");

var _store = require("../../store");

var _actions = require("../../actions");

var _routes = _interopRequireDefault(require("../../routes"));

var _templateObject;

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { (0, _defineProperty2.default)(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

// We need to store the post ID so we can remove the lock when navigating to a different page (old ID won't be available anymore)
let postLockID = null;

const AdminEditor = props => {
  var _sites$siteID2, _sites$siteID3, _sites$siteID3$editor, _sites$siteID3$editor2, _post$locked2, _sites$siteID4, _sites$siteID4$editor, _sites$siteID5, _sites$siteID5$editor, _sites$siteID5$editor2, _sites$siteID6, _sites$siteID6$editor, _sites$siteID6$editor2;

  const {
    defaultComponent
  } = props;
  const [{
    config,
    cmsState: {
      sites,
      siteID
    },
    editorState: {
      post,
      editorSettings
    }
  }, dispatch] = (0, _store.useStore)();
  const postID = (0, _react.useMemo)(() => {
    var _sites$siteID;

    return ((_sites$siteID = sites[siteID]) === null || _sites$siteID === void 0 ? void 0 : _sites$siteID.id) && (0, _utils.getPostID)(sites[siteID]);
  }, [(_sites$siteID2 = sites[siteID]) === null || _sites$siteID2 === void 0 ? void 0 : _sites$siteID2.id, window.location.pathname]); // Timer for lock check

  const [postLockTimer, setPostLockTimer] = (0, _react.useState)(0); // Determine if sidebar should be open on default when visiting the editor

  const [sidebarActive, setSidebarActive] = (0, _react.useState)(!!((_sites$siteID3 = sites[siteID]) !== null && _sites$siteID3 !== void 0 && (_sites$siteID3$editor = _sites$siteID3.editorOptions) !== null && _sites$siteID3$editor !== void 0 && (_sites$siteID3$editor2 = _sites$siteID3$editor.sidebar) !== null && _sites$siteID3$editor2 !== void 0 && _sites$siteID3$editor2.defaultOpen));
  const template = (0, _utils.getTemplateByPost)(post, config === null || config === void 0 ? void 0 : config.fields);
  const Component = template === null || template === void 0 ? void 0 : template.component;
  const loaded = postID && (post === null || post === void 0 ? void 0 : post.id) === postID; // For the post lock functionality we need 4 useEffect functions to cover the whole process
  // 1. Set up interval function on initial load and remove post lock in case user leaves the editor
  // 2. Refresh the lock status every couple of seconds or check if post is still locked
  // 3. Inform user who is currently editing the post by displaying the take over dialog
  // 4. Remove lock status from old post in case user navigates away via editor link

  (0, _react.useEffect)(() => {
    // Activate postLockTimer for post locking
    const intervalID = setInterval(() => {
      setPostLockTimer(time => time + 1);
    }, 60000); // 60 seconds

    return () => {
      clearInterval(intervalID);

      if (loaded && !post.locked) {
        // Remove post lock once we leave the post editor
        removePostLock(postID);
      }
    };
  }, []);
  (0, _react.useEffect)(() => {
    // Skip initial fetch (postLockTimer = 0) because we're already setting the status on initial getPost fetch in WP
    if (loaded && postLockTimer) {
      if (post !== null && post !== void 0 && post.locked) {
        // Fetch post again in case it's locked to determine if other user is still editing
        loadPost();
      } else {
        // Refresh the post lock status to inform WordPress that we are still editing
        refreshPostLock();
      }
    }
  }, [postLockTimer]);
  (0, _react.useEffect)(() => {
    // Remove previous post ID in case user navigates to a different page
    if (postLockID) {
      removePostLock(postLockID);
    } // Set new post id


    postLockID = postID;
  }, [postID]);
  (0, _react.useEffect)(() => {
    var _post$locked;

    if (post !== null && post !== void 0 && (_post$locked = post.locked) !== null && _post$locked !== void 0 && _post$locked.id) {
      handleOpenTakeOverDialog();
    }
  }, [post === null || post === void 0 ? void 0 : (_post$locked2 = post.locked) === null || _post$locked2 === void 0 ? void 0 : _post$locked2.id]);
  (0, _react.useEffect)(() => {
    loadPost(); // Add fresh copy of editor to state

    dispatch({
      type: 'ADD_EDITOR_SITE',
      payload: sites[siteID]
    });
    return () => dispatch({
      type: 'CLEAR_EDITOR'
    });
  }, [postID]);
  (0, _reactUseKeypress.default)('Escape', () => {
    !editorSettings.fullscreen && setSidebarActive(!sidebarActive);
  });

  const loadPost = async () => {
    if (!postID) {
      return;
    }

    const result = await _actions.postActions.getPost({
      siteID,
      postID
    }, dispatch, config);

    if (result) {
      dispatch({
        type: 'ADD_POST',
        payload: _objectSpread(_objectSpread({}, result), {}, {
          siteID
        })
      });
      dispatch({
        type: 'ADD_EDITOR_POST',
        payload: _objectSpread(_objectSpread({}, result), {}, {
          siteID
        })
      });
    }
  };

  const handleTakeOver = async () => {
    await _actions.postActions.takeOverPost({
      siteID,
      id: postID
    }, dispatch, config);
  };

  const handleOpenTakeOverDialog = () => {
    dispatch({
      type: 'SET_DIALOG',
      payload: {
        open: true,
        title: 'Locked',
        component: /*#__PURE__*/_react.default.createElement(_antd.Space, {
          direction: "vertical",
          size: 20
        }, /*#__PURE__*/_react.default.createElement(_antd.Typography.Text, null, "This content is currently locked. If you take over, ", post.locked.email, " will be blocked from continuing to edit."), /*#__PURE__*/_react.default.createElement(_antd.Space, null, /*#__PURE__*/_react.default.createElement(_antd.Button, {
          onClick: () => {
            dispatch({
              type: 'CLOSE_DIALOG'
            });
            (0, _router.navigate)((0, _routes.default)("collection", {
              siteID,
              postTypeID: (post === null || post === void 0 ? void 0 : post.postTypeID) || 'page'
            }));
          },
          children: "Dashboard"
        }), /*#__PURE__*/_react.default.createElement(_antd.Button, {
          onClick: () => dispatch({
            type: 'CLOSE_DIALOG'
          }),
          children: "Preview"
        }), /*#__PURE__*/_react.default.createElement(_antd.Button, {
          onClick: handleTakeOver,
          type: "primary",
          children: "Take Over"
        })))
      }
    });
  };

  const refreshPostLock = async () => {
    await _actions.postActions.refreshPostLock({
      siteID,
      id: postID
    }, dispatch, config);
  };

  const removePostLock = async id => {
    await _actions.postActions.removePostLock({
      siteID,
      id
    }, dispatch, config);
  };

  const handleToggleSidebar = () => {
    if (sidebarActive) {
      _antd.message.info({
        content: /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, "Press ", /*#__PURE__*/_react.default.createElement(_antd.Typography.Text, {
          keyboard: true
        }, "ESC"), " to reopen sidebar")
      });
    }

    setSidebarActive(!sidebarActive);
  };

  const sidebarOptions = _objectSpread(_objectSpread({}, (_sites$siteID4 = sites[siteID]) === null || _sites$siteID4 === void 0 ? void 0 : (_sites$siteID4$editor = _sites$siteID4.editorOptions) === null || _sites$siteID4$editor === void 0 ? void 0 : _sites$siteID4$editor.sidebar), {}, {
    active: sidebarActive
  });

  if (!postID) {
    return defaultComponent;
  }

  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_EditorWrapper.default, {
    sidebarActive: sidebarActive,
    loaded: loaded,
    locked: !!(post !== null && post !== void 0 && post.locked)
  }, loaded ? /*#__PURE__*/_react.default.createElement(_Editor.default, (0, _extends2.default)({
    postID: postID
  }, props, {
    sidebarOptions: sidebarOptions
  })) : /*#__PURE__*/_react.default.createElement(_Loader.default, null)), loaded && /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, post !== null && post !== void 0 && post.locked ? /*#__PURE__*/_react.default.createElement(FloatingButton, {
    sidebarPosition: (_sites$siteID5 = sites[siteID]) === null || _sites$siteID5 === void 0 ? void 0 : (_sites$siteID5$editor = _sites$siteID5.editorOptions) === null || _sites$siteID5$editor === void 0 ? void 0 : (_sites$siteID5$editor2 = _sites$siteID5$editor.sidebar) === null || _sites$siteID5$editor2 === void 0 ? void 0 : _sites$siteID5$editor2.position
  }, /*#__PURE__*/_react.default.createElement(_antd.Button, {
    icon: /*#__PURE__*/_react.default.createElement(_icons.LockOutlined, null),
    onClick: handleOpenTakeOverDialog,
    size: "large",
    type: "primary"
  })) : /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, sidebarActive ? /*#__PURE__*/_react.default.createElement(_Sidebar.default, {
    className: "jam-cms",
    editable: !!Component,
    onToggleSidebar: handleToggleSidebar
  }) : /*#__PURE__*/_react.default.createElement(FloatingButton, {
    sidebarPosition: (_sites$siteID6 = sites[siteID]) === null || _sites$siteID6 === void 0 ? void 0 : (_sites$siteID6$editor = _sites$siteID6.editorOptions) === null || _sites$siteID6$editor === void 0 ? void 0 : (_sites$siteID6$editor2 = _sites$siteID6$editor.sidebar) === null || _sites$siteID6$editor2 === void 0 ? void 0 : _sites$siteID6$editor2.position
  }, /*#__PURE__*/_react.default.createElement(_antd.Button, {
    icon: /*#__PURE__*/_react.default.createElement(_icons.EditOutlined, null),
    onClick: handleToggleSidebar,
    size: "large",
    type: "primary"
  })))));
};

const FloatingButton = (0, _styledComponents.default)('div')(_templateObject || (_templateObject = (0, _taggedTemplateLiteral2.default)(["\n  position: fixed;\n  left: ", ";\n  right: ", ";\n  bottom: 200px;\n  z-index: 99999;\n\n  .ant-btn-icon-only.ant-btn-lg {\n    border-radius: ", ";\n  }\n"])), (_ref) => {
  let {
    sidebarPosition
  } = _ref;
  return sidebarPosition === 'left' ? 0 : 'unset';
}, (_ref2) => {
  let {
    sidebarPosition
  } = _ref2;
  return sidebarPosition === 'left' ? 'unset' : 0;
}, (_ref3) => {
  let {
    sidebarPosition
  } = _ref3;
  return sidebarPosition === 'left' ? '0 2px 2px 0' : '2px 0 0 2px';
});
var _default = AdminEditor;
exports.default = _default;