"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _taggedTemplateLiteral2 = _interopRequireDefault(require("@babel/runtime/helpers/taggedTemplateLiteral"));

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));

var _react = _interopRequireWildcard(require("react"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _axios = _interopRequireDefault(require("axios"));

var _lodash = require("lodash");

var _antd = require("antd");

var _Seo = _interopRequireDefault(require("../Seo"));

var _useForceUpdate = _interopRequireDefault(require("../../hooks/useForceUpdate"));

var _utils = require("../../utils");

var _store = require("../../store");

var _templateObject;

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { (0, _defineProperty2.default)(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return typeof key === "symbol" ? key : String(key); }

function _toPrimitive(input, hint) { if (typeof input !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (typeof res !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }

// We need to store the template ID in a global variable to detect template changes.
// Using useEffect doesn't work, because a template switch will immediately render the new component with wrong props.
let globalTemplateID = '';

const Editor = props => {
  var _sites$siteID, _post$translations, _site$languages, _config$fields2;

  const {
    postID,
    pageContext: {
      themeOptions,
      siteTitle
    },
    defaultComponent,
    sidebarOptions
  } = props,
        rest = (0, _objectWithoutProperties2.default)(props, ["postID", "pageContext", "defaultComponent", "sidebarOptions"]);
  const [{
    config,
    cmsState: {
      sites,
      siteID
    },
    editorState: {
      site,
      post
    }
  }] = (0, _store.useStore)(); // GraphQL query result

  const [query, setQuery] = (0, _react.useState)(null);
  const [queryError, setQueryError] = (0, _react.useState)(false);
  const forceUpdate = (0, _useForceUpdate.default)();
  const template = (0, _utils.getTemplateByPost)(post, config === null || config === void 0 ? void 0 : config.fields);
  const Component = template === null || template === void 0 ? void 0 : template.component; // The 'true' template id is a combination of id and post type.

  const templateID = "".concat(template === null || template === void 0 ? void 0 : template.id, "-").concat((post === null || post === void 0 ? void 0 : post.archivePostType) || (post === null || post === void 0 ? void 0 : post.postTypeID));
  const postsPerPage = post === null || post === void 0 ? void 0 : post.archivePostsPerPage; // We need to check if post is front page to return the correct basePath for pagination

  const isFrontPage = postID === ((_sites$siteID = sites[siteID]) === null || _sites$siteID === void 0 ? void 0 : _sites$siteID.frontPage) || (post === null || post === void 0 ? void 0 : (_post$translations = post.translations) === null || _post$translations === void 0 ? void 0 : _post$translations[site === null || site === void 0 ? void 0 : (_site$languages = site.languages) === null || _site$languages === void 0 ? void 0 : _site$languages.defaultLanguage]) === (site === null || site === void 0 ? void 0 : site.frontPage);
  const pathname = window.location.pathname.replace(/\/$/, '');

  const isNumber = n => !isNaN(parseFloat(n)) && !isNaN(n - 0); // The pagination object will be available once we have the post id and therefore template id


  const pagination = (0, _react.useMemo)(() => {
    var _sites$siteID2, _sites$siteID2$postTy, _sites$siteID2$postTy2;

    let pagination = {}; // We can't generate the pagination object for protected pages because those don't have access to the site object and therefore not to the number of posts.

    if ((template === null || template === void 0 ? void 0 : template.id) === 'archive' && (_sites$siteID2 = sites[siteID]) !== null && _sites$siteID2 !== void 0 && (_sites$siteID2$postTy = _sites$siteID2.postTypes) !== null && _sites$siteID2$postTy !== void 0 && (_sites$siteID2$postTy2 = _sites$siteID2$postTy[post === null || post === void 0 ? void 0 : post.archivePostType]) !== null && _sites$siteID2$postTy2 !== void 0 && _sites$siteID2$postTy2.posts) {
      var _sites$siteID3, _sites$siteID3$postTy, _sites$siteID3$postTy2;

      // Get the page number if exists
      const page = isNumber(pathname.substring(pathname.lastIndexOf('/') + 1)) ? parseInt(pathname.substring(pathname.lastIndexOf('/') + 1)) : 1; // We only wanna query for published posts
      // And in case the post has a language assigned we wanna filter the posts accordingly

      const filteredPosts = Object.values((_sites$siteID3 = sites[siteID]) === null || _sites$siteID3 === void 0 ? void 0 : (_sites$siteID3$postTy = _sites$siteID3.postTypes) === null || _sites$siteID3$postTy === void 0 ? void 0 : (_sites$siteID3$postTy2 = _sites$siteID3$postTy[post === null || post === void 0 ? void 0 : post.archivePostType]) === null || _sites$siteID3$postTy2 === void 0 ? void 0 : _sites$siteID3$postTy2.posts).filter(o => o.status === 'publish').filter(o => post !== null && post !== void 0 && post.language ? o.language === (post === null || post === void 0 ? void 0 : post.language) : o);
      const numberOfPosts = filteredPosts.length;
      pagination = {
        basePath: (0, _utils.generateSlug)({
          site,
          postTypeID: post.postTypeID,
          postID: post.id,
          leadingSlash: true,
          trailingSlash: true
        }),
        numberOfPosts,
        postsPerPage,
        numberOfPages: Math.ceil(numberOfPosts / postsPerPage),
        page
      };
    }

    return pagination;
  }, [isFrontPage, templateID, postsPerPage, pathname]); // Load query in case post has one assigned

  (0, _react.useEffect)(() => {
    const loadQuery = async () => {
      var _post$language;

      // TODO: Move to utils function
      const cleanedUrl = config === null || config === void 0 ? void 0 : config.source.replace(/\/+$/, '');
      let query = template.query; // We need to replace any static variables with the correct values here

      query = query.replaceAll('$language', post === null || post === void 0 ? void 0 : (_post$language = post.language) === null || _post$language === void 0 ? void 0 : _post$language.toUpperCase());

      try {
        var _result$data, _result$data$errors;

        const result = await _axios.default.post("".concat(cleanedUrl, "/graphql"), {
          query
        });

        if (result !== null && result !== void 0 && (_result$data = result.data) !== null && _result$data !== void 0 && (_result$data$errors = _result$data.errors) !== null && _result$data$errors !== void 0 && _result$data$errors.length) {
          setQueryError(result.data.errors);
        } else if (result !== null && result !== void 0 && result.data) {
          setQuery(result.data);
        }
      } catch (err) {
        console.log(err);
      }
    }; // Update global template id


    globalTemplateID = templateID;

    if (template !== null && template !== void 0 && template.query) {
      loadQuery();
    } else {
      // If the user toggles between two templates without a query, then simply resetting the query with setQuery(null) doesn't trigger an re-render.
      // That's why we use a custom hook to mimic a state update.
      forceUpdate();
    }
  }, [templateID]);

  const getPostData = () => {
    // Generate query variable i.e. 'wpPage'
    const nodeType = "wp".concat(post.postTypeID.charAt(0).toUpperCase() + post.postTypeID.slice(1)); // Destructure query data in case user requested more information about post (i.e. wpPost comments)

    const _ref = (query === null || query === void 0 ? void 0 : query.data) || {},
          {
      [nodeType]: nodeTypeQueryData
    } = _ref,
          otherQueryData = (0, _objectWithoutProperties2.default)(_ref, [nodeType].map(_toPropertyKey)); // Generate default page data


    const data = _objectSpread({}, otherQueryData);

    const nodeTypeData = _objectSpread({
      id: post.id,
      title: post.title,
      date: post.createdAt,
      featuredImage: post.featuredImage,
      postTypeID: post.postTypeID
    }, (0, _utils.formatTaxonomiesForEditor)(post, site));

    data[nodeType] = _objectSpread(_objectSpread({}, nodeTypeQueryData), nodeTypeData);
    const acfData = (0, _utils.formatFieldsToProps)({
      global: false,
      content: post.content,
      site,
      template
    });

    if (post.postTypeID === 'page') {
      (0, _lodash.set)(data, "".concat(nodeType, ".template.acf"), acfData);
    } else {
      (0, _lodash.set)(data, "".concat(nodeType, ".acf"), acfData);
    }

    return data;
  }; // If there is a query, we need to wait for it.
  // We also need to wait until global and local template ID are identical to prevent an error when a user switches between two template where both have queries.


  let loaded = true;

  if (!(site !== null && site !== void 0 && site.id) || !(post !== null && post !== void 0 && post.id) || template !== null && template !== void 0 && template.query && !query || globalTemplateID !== templateID) {
    loaded = false;
  }

  const renderComponent = () => {
    var _sites$siteID4, _config$fields, _sites$siteID5, _sites$siteID5$langua, _sites$siteID5$langua2;

    const pageContext = {
      siteTitle: ((_sites$siteID4 = sites[siteID]) === null || _sites$siteID4 === void 0 ? void 0 : _sites$siteID4.title) || siteTitle,
      seo: post === null || post === void 0 ? void 0 : post.seo,
      pagination,
      jamCMS: {
        sidebar: _objectSpread({}, sidebarOptions)
      },
      themeOptions: site !== null && site !== void 0 && site.themeOptions ? (0, _utils.formatFieldsToProps)({
        global: true,
        themeOptions: config === null || config === void 0 ? void 0 : (_config$fields = config.fields) === null || _config$fields === void 0 ? void 0 : _config$fields.themeOptions,
        content: site === null || site === void 0 ? void 0 : site.themeOptions,
        site,
        template
      }) : themeOptions
    }; // Check if post type supports languages

    const postTypeSupportsLanguages = !!((_sites$siteID5 = sites[siteID]) !== null && _sites$siteID5 !== void 0 && (_sites$siteID5$langua = _sites$siteID5.languages) !== null && _sites$siteID5$langua !== void 0 && (_sites$siteID5$langua2 = _sites$siteID5$langua.postTypes) !== null && _sites$siteID5$langua2 !== void 0 && _sites$siteID5$langua2.find(s => s === post.postTypeID));

    if (postTypeSupportsLanguages) {
      pageContext.language = {};
      pageContext.translations = [];

      const getLanguageParameters = post => {
        var _sites$siteID$languag, _sites$siteID$languag2;

        const {
          slug,
          name,
          locale
        } = ((_sites$siteID$languag = sites[siteID].languages) === null || _sites$siteID$languag === void 0 ? void 0 : (_sites$siteID$languag2 = _sites$siteID$languag.languages) === null || _sites$siteID$languag2 === void 0 ? void 0 : _sites$siteID$languag2.find(o => o.slug === post.language)) || {};
        return slug ? {
          slug,
          name,
          locale
        } : {};
      }; // Add language information to pageContext if applicable


      if (post !== null && post !== void 0 && post.language) {
        pageContext.language = getLanguageParameters(post);
      }

      if (post !== null && post !== void 0 && post.translations) {
        Object.values(post.translations).map(id => {
          const translatedPost = sites[siteID].postTypes[post.postTypeID].posts[id];

          if (translatedPost) {
            pageContext.translations.push({
              title: translatedPost.title,
              uri: (0, _utils.generateSlug)({
                site: sites[siteID],
                postTypeID: post.postTypeID,
                postID: translatedPost.id,
                leadingSlash: true
              }),
              language: getLanguageParameters(translatedPost)
            });
          }
        });
      }
    }

    return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_Seo.default, (0, _extends2.default)({}, props, {
      pageContext: pageContext
    })), /*#__PURE__*/_react.default.createElement(Component, (0, _extends2.default)({}, rest, {
      data: getPostData(),
      pageContext: pageContext
    })));
  };

  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, loaded ? /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, queryError ? /*#__PURE__*/_react.default.createElement(EmptyContainer, {
    className: "jam-cms",
    alignItems: 'flex-start',
    textAlign: 'left'
  }, /*#__PURE__*/_react.default.createElement(_antd.Alert, {
    style: {
      width: '100%'
    },
    message: "Query failed",
    type: "error",
    showIcon: true,
    description: queryError.map(o => o.message).join(', ')
  })) : /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, !!Component && post !== null && post !== void 0 && post.content ? renderComponent() : /*#__PURE__*/_react.default.createElement(EmptyContainer, {
    className: "jam-cms",
    alignItems: 'center',
    textAlign: 'center'
  }, /*#__PURE__*/_react.default.createElement(_antd.Empty, {
    imageStyle: {
      height: 120
    },
    description: 'No Template'
  })))) : /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_Seo.default, props), /*#__PURE__*/_react.default.cloneElement(defaultComponent, {
    pageContext: loaded ? {
      pagination,
      themeOptions: (0, _utils.formatFieldsToProps)({
        themeOptions: config === null || config === void 0 ? void 0 : (_config$fields2 = config.fields) === null || _config$fields2 === void 0 ? void 0 : _config$fields2.themeOptions,
        content: site === null || site === void 0 ? void 0 : site.themeOptions,
        site
      })
    } : props.pageContext
  })));
};

const EmptyContainer = (0, _styledComponents.default)('div')(_templateObject || (_templateObject = (0, _taggedTemplateLiteral2.default)(["\n  display: flex;\n  justify-content: center;\n  align-items: ", ";\n  height: 100vh;\n  text-align: ", ";\n  background: transparent;\n  padding: 20px;\n"])), (_ref2) => {
  let {
    alignItems
  } = _ref2;
  return alignItems;
}, (_ref3) => {
  let {
    textAlign
  } = _ref3;
  return textAlign;
});
var _default = Editor;
exports.default = _default;