"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getAuthUser = exports.refreshToken = exports.resetPassword = exports.forgetPassword = exports.signIn = void 0;

var _axios = _interopRequireDefault(require("axios"));

var _utils = require("../utils");

// TODO: add trailing slash function to utils and pass in endpoint via settings (doesn't need to be /graphql)
const getEndpoint = url => "".concat(url.replace(/\/+$/, ''), "/graphql");

const signIn = async (_ref, url) => {
  let {
    email,
    password
  } = _ref;

  try {
    var _result$data, _result$data$data, _result$data$data$log;

    const endpoint = getEndpoint(url);
    const result = await _axios.default.post(endpoint, {
      query: "\n        mutation  {\n          login(\n            input: {\n              username: \"".concat(email, "\"\n              password: \"").concat(password, "\"\n              clientMutationId: \"login\"\n            }\n          ) {\n            authToken\n            refreshToken\n            user {\n              jwtAuthExpiration\n              capabilities\n            }\n          }\n        }\n      ")
    }); // Format response accordingly

    if (result !== null && result !== void 0 && (_result$data = result.data) !== null && _result$data !== void 0 && (_result$data$data = _result$data.data) !== null && _result$data$data !== void 0 && (_result$data$data$log = _result$data$data.login) !== null && _result$data$data$log !== void 0 && _result$data$data$log.authToken) {
      const {
        data: {
          data: {
            login: {
              authToken,
              refreshToken,
              user: {
                jwtAuthExpiration,
                capabilities
              }
            }
          }
        }
      } = result;
      const formattedCapabilities = {};
      capabilities.map(s => {
        formattedCapabilities[s] = true;
      });
      return {
        authToken,
        refreshToken,
        jwtAuthExpiration,
        capabilities: formattedCapabilities
      };
    }

    return result === null || result === void 0 ? void 0 : result.data;
  } catch (err) {
    console.log(err);
  }
};

exports.signIn = signIn;

const forgetPassword = async (_ref2, url) => {
  let {
    email
  } = _ref2;
  const endpoint = getEndpoint(url);
  const result = await _axios.default.post(endpoint, {
    query: "\n      mutation {\n        sendPasswordResetEmail(\n          input: {\n            username: \"".concat(email, "\"\n            clientMutationId: \"forgotPassword\"\n          }\n        ) {\n          user {\n            email\n          }\n        }\n      }\n    ")
  });
  return result === null || result === void 0 ? void 0 : result.data;
};

exports.forgetPassword = forgetPassword;

const resetPassword = async (_ref3, url) => {
  let {
    key,
    login,
    password
  } = _ref3;
  const endpoint = getEndpoint(url);
  const result = await _axios.default.post(endpoint, {
    query: "\n      mutation {\n        resetUserPassword(\n          input: {\n            key: \"".concat(key, "\"\n            login: \"").concat(login, "\"\n            password: \"").concat(password, "\"\n            clientMutationId: \"changePassword\"\n          }\n        ) {\n          user {\n            email\n          }\n        }\n      }\n    ")
  });
  return result === null || result === void 0 ? void 0 : result.data;
};

exports.resetPassword = resetPassword;

const refreshToken = async (_ref4, dispatch, config) => {
  var _result$data2, _result$data2$data;

  let {
    refreshToken
  } = _ref4;
  const endpoint = getEndpoint(config.source);
  const result = await _axios.default.post(endpoint, {
    query: "\n      mutation {\n        refreshJwtAuthToken(\n          input: {\n            jwtRefreshToken: \"".concat(refreshToken, "\"\n            clientMutationId: \"refreshToken\"\n          }\n        ) {\n          authToken\n        }\n      }\n    ")
  });

  if (result !== null && result !== void 0 && (_result$data2 = result.data) !== null && _result$data2 !== void 0 && (_result$data2$data = _result$data2.data) !== null && _result$data2$data !== void 0 && _result$data2$data.refreshJwtAuthToken) {
    const {
      data: {
        data: {
          refreshJwtAuthToken: {
            authToken
          }
        }
      }
    } = result;
    return authToken;
  }

  return false;
};

exports.refreshToken = refreshToken;

const getAuthUser = async (_ref5, dispatch, config) => {
  let {} = _ref5;
  const endpoint = getEndpoint(config.source);

  const user = _utils.auth.getUser();

  if (user !== null && user !== void 0 && user.authToken) {
    var _result$data3, _result$data3$data;

    const result = await _axios.default.post(endpoint, {
      query: "\n        query {\n          viewer {\n            id\n            email\n            capabilities\n            jwtAuthExpiration\n            roles {\n              nodes {\n                name\n              }\n            }\n          }\n        }\n      "
    }, {
      headers: {
        Authorization: "Bearer ".concat(user.authToken)
      }
    });

    if (result !== null && result !== void 0 && (_result$data3 = result.data) !== null && _result$data3 !== void 0 && (_result$data3$data = _result$data3.data) !== null && _result$data3$data !== void 0 && _result$data3$data.viewer) {
      const {
        data: {
          data: {
            viewer: {
              id,
              email,
              capabilities,
              roles,
              jwtAuthExpiration
            }
          }
        }
      } = result;
      const formattedCapabilities = {};
      capabilities.map(s => {
        formattedCapabilities[s] = true;
      });
      return {
        id,
        email,
        capabilities: formattedCapabilities,
        roles: roles === null || roles === void 0 ? void 0 : roles.nodes.map(o => o.name),
        jwtAuthExpiration
      };
    }
  }

  return false;
};

exports.getAuthUser = getAuthUser;