"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.sitesReducer = exports.cmsState = void 0;

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _immer = _interopRequireDefault(require("immer"));

var _lodash = require("lodash");

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { (0, _defineProperty2.default)(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

const DEFAULT_STATE = {
  siteID: null,
  sites: {},
  activeLanguage: null,
  deploymentImage: ''
};

const cmsState = _objectSpread({}, DEFAULT_STATE);

exports.cmsState = cmsState;

const sitesReducer = (state, action) => {
  const {
    payload
  } = action;
  return (0, _immer.default)(state, draft => {
    var _draft$sites, _draft$sites$payload$, _draft$sites$payload$2, _draft$sites$payload$3;

    switch (action.type) {
      case "SET_DEPLOYMENT_IMAGE":
        draft.deploymentImage = payload;
        break;

      /******************************
       * Sites
       ******************************/

      case "ADD_SITES":
        draft.sites = payload;
        break;

      case "ADD_SITE":
        draft.siteID = payload.id;
        (0, _lodash.set)(draft, "sites.".concat(payload.id), payload); // Set active language if applicable

        if (!!(payload !== null && payload !== void 0 && payload.languages) && !draft.activeLanguage) {
          draft.activeLanguage = payload.languages.defaultLanguage || 'all';
        }

        break;

      case "ADD_SITE_SETTING":
        (0, _lodash.set)(draft, "sites.".concat(payload.id, ".").concat(payload.key), payload.value);
        break;

      case "DELETE_SITE":
        draft.siteID = null;
        delete draft.sites[payload.id];
        break;

      /******************************
       * Collections
       ******************************/

      case "UPDATE_COLLECTION":
        (0, _lodash.set)(draft, "sites.".concat(payload.siteID, ".postTypes.").concat(payload.id), payload);
        break;

      /******************************
       * Terms
       ******************************/

      case "ADD_TERM":
        (0, _lodash.set)(draft, "sites.".concat(payload.siteID, ".taxonomies.").concat(payload.taxonomyID, ".terms.").concat(payload.id), payload);
        break;

      case "UPDATE_TERM":
        (0, _lodash.set)(draft, "sites.".concat(payload.siteID, ".taxonomies.").concat(payload.taxonomyID, ".terms.").concat(payload.id), payload);
        break;

      case "DELETE_TERM":
        // Payload: siteID, taxonomyID, id
        // Get the term that needs to be deleted
        const termToDelete = draft.sites[payload.siteID].taxonomies[payload.taxonomyID].terms[payload.id]; // In case the term has translations, we wanna loop trough them and remove the reference to the term that has been deleted

        if (termToDelete.translations) {
          Object.keys(termToDelete.translations).map(language => {
            // This is the term id of the translated term
            const termID = termToDelete.translations[language];
            delete draft.sites[payload.siteID].taxonomies[payload.taxonomyID].terms[termID].translations[termToDelete.language];
          });
        } // Finally we can remove the actual term


        delete draft.sites[payload.siteID].taxonomies[payload.taxonomyID].terms[payload.id];
        break;

      /******************************
       * Posts
       ******************************/

      case "ADD_POST":
        (0, _lodash.set)(draft, "sites.".concat(payload.siteID, ".postTypes.").concat(payload.postTypeID, ".posts.").concat(payload.id), payload);
        break;

      case "DELETE_POST":
        // Payload: siteID, postTypeID, id
        // Get the post that needs to be deleted
        const postToDelete = draft.sites[payload.siteID].postTypes[payload.postTypeID].posts[payload.id]; // In case the post has translations, we wanna loop trough them and remove the reference to the post that has been deleted

        if (postToDelete.translations) {
          Object.keys(postToDelete.translations).map(language => {
            // This is the post id of the translated post
            const postID = postToDelete.translations[language];
            delete draft.sites[payload.siteID].postTypes[payload.postTypeID].posts[postID].translations[postToDelete.language];
          });
        } // Finally we can remove the actual post


        delete draft.sites[payload.siteID].postTypes[payload.postTypeID].posts[payload.id];
        break;

      case "DELETE_POSTS":
        // Payload: siteID, postTypeID, postIDs
        payload.postIDs.map(id => {
          // Get the post that needs to be deleted
          const postToDelete = draft.sites[payload.siteID].postTypes[payload.postTypeID].posts[id]; // In case the post has translations, we wanna loop trough them and remove the reference to the post that has been deleted

          if (postToDelete.translations) {
            Object.keys(postToDelete.translations).map(language => {
              // This is the post id of the translated post
              const postID = postToDelete.translations[language];
              delete draft.sites[payload.siteID].postTypes[payload.postTypeID].posts[postID].translations[postToDelete.language];
            });
          } // Finally we can remove the actual post


          delete draft.sites[payload.siteID].postTypes[payload.postTypeID].posts[id];
        });
        break;

      /******************************
       * Language
       ******************************/

      case "SET_ACTIVE_LANGUAGE":
        draft.activeLanguage = payload;
        break;

      case "UPDATE_LANGUAGES":
        (0, _lodash.set)(draft, "sites.".concat(payload.siteID, ".languages"), payload.languages);
        break;

      case "DELETE_LANGUAGE":
        draft.sites[payload.siteID].languages.languages = (_draft$sites = draft.sites) === null || _draft$sites === void 0 ? void 0 : (_draft$sites$payload$ = _draft$sites[payload === null || payload === void 0 ? void 0 : payload.siteID]) === null || _draft$sites$payload$ === void 0 ? void 0 : (_draft$sites$payload$2 = _draft$sites$payload$.languages) === null || _draft$sites$payload$2 === void 0 ? void 0 : (_draft$sites$payload$3 = _draft$sites$payload$2.languages) === null || _draft$sites$payload$3 === void 0 ? void 0 : _draft$sites$payload$3.filter(o => o.id !== (payload === null || payload === void 0 ? void 0 : payload.id)); // Reset language if active language gets deleted

        if (draft.activeLanguage === payload.slug) {
          draft.activeLanguage = 'all';
        } // Reset default language in case user deletes it


        if (draft.sites[payload.siteID].languages.defaultLanguage === payload.slug) {
          draft.sites[payload.siteID].languages.defaultLanguage = false;
        }

        break;

      case "UPDATE_LANGUAGE_SETTINGS":
        draft.sites[payload.siteID].languages = _objectSpread(_objectSpread({}, draft.sites[payload.siteID].languages), payload.settings);
        break;

      case "SET_LANGUAGE_IN_MASS":
        // Payload: siteID, postTypeID / taxonomyID, type, ids, language
        payload.ids.map(id => {
          if (payload.type === 'post') {
            (0, _lodash.set)(draft, "sites.".concat(payload.siteID, ".postTypes.").concat(payload.postTypeID, ".posts.").concat(id, ".language"), payload.language);
          } else {
            (0, _lodash.set)(draft, "sites.".concat(payload.siteID, ".taxonomies.").concat(payload.taxonomyID, ".terms.").concat(id, ".language"), payload.language);
          }
        });
        break;

      /******************************
       * Clear
       ******************************/

      case "CLEAR_POST_STATE":
        draft.siteID = null;
        draft.sites = {};
        draft.activeLanguage = null;
        draft.deploymentImage = '';
        break;

      default:
    }
  });
};

exports.sitesReducer = sitesReducer;